==> testinglibrary-0.2.8.tgz: package/playwright.config.js <==
// @ts-check
const { defineConfig, devices } = require('@playwright/test');
const path = require('path');
const numCPUs = require('os').cpus().length;

/**
 * Read environment variables from file.
 * https://github.com/motdotla/dotenv
 */
// require('dotenv').config();

/**
 * @see https://playwright.dev/docs/test-configuration
 */
export default defineConfig({
  testDir: path.join(path.resolve(process.cwd()), 'uat'),
  outputDir: path.join(process.cwd(), 'uat', 'test-results'),
  /* Run tests in files in parallel */
  fullyParallel: true,
  /* Fail the build on CI if you accidentally left test.only in the source code. */
  forbidOnly: !!process.env.CI,
  /* Retry on CI only */
  retries: process.env.CI ? 2 : 0,
  /* Reporter to use. See https://playwright.dev/docs/test-reporters */
  reporter: [['html', { outputFolder: path.join(process.cwd(), 'uat', 'playwright-report'), open: "always" }]],
  timeout: 60 * 1000,
  expect: {
    timeout: 5 * 1000,
  },

  /* Shared settings for all the projects below. See https://playwright.dev/docs/api/class-testoptions. */
  use: {
    /* Base URL to use in actions like `await page.goto('/')`. */
    //baseURL: process.env.domain,

    /* Collect trace when retrying the failed test. See https://playwright.dev/docs/trace-viewer */
    trace: 'on',
    video: {
      mode: 'on',
      size: { width: 640, height: 480 }
    }
  },

  /* Configure projects for major browsers */
  projects: [
    { name: 'setup', testMatch: /.*\.setup\.js/ },
    {
      name: 'chromium',
      use: {
        ...devices['Desktop Chrome'],
        storageState: path.resolve(process.cwd(), 'uat', 'playwright/.auth/user.json')
      },
      dependencies: ['setup'],
    },

    {
      name: 'firefox',
      timeout: 4 * 60 * 1000,
      expect: {
        timeout: 80 * 1000,
      },
      use: {
        ...devices['Desktop Firefox'],
        storageState: path.resolve(process.cwd(), 'uat', 'playwright/.auth/user.json')
      },
      dependencies: ['setup'],
    },

    {
      name: 'webkit',
      timeout: 2 * 60 * 1000,
      expect: {
        timeout: 80 * 1000,
      },
      use: {
        ...devices['Desktop Safari'],
        storageState: path.resolve(process.cwd(), 'uat', 'playwright/.auth/user.json')
      },
      dependencies: ['setup'],
    },

    /* Test against mobile viewports. */
    // {
    //   name: 'Mobile Chrome',
    //   use: { ...devices['Pixel 5'] },
    // },
    // {
    //   name: 'Mobile Safari',
    //   use: { ...devices['iPhone 12'] },
    // },

    /* Test against branded browsers. */
    // {
    //   name: 'Microsoft Edge',
    //   use: { ...devices['Desktop Edge'], channel: 'msedge' },
    // },
    // {
    //   name: 'Google Chrome',
    //   use: { ...devices['Desktop Chrome'], channel: 'chrome' },
    // },
  ],

  /* Run your local dev server before starting the tests */
  // webServer: {
  //   command: 'npm run start',
  //   url: 'http://127.0.0.1:3000',
  //   reuseExistingServer: !process.env.CI,
  // },
});

==> testinglibrary-0.3.0.tgz: package/playwright.config.js <==
// @ts-check
const { defineConfig, devices } = require('@playwright/test');
const path = require('path');
const numCPUs = require('os').cpus().length;

/**
 * Read environment variables from file.
 * https://github.com/motdotla/dotenv
 */
// require('dotenv').config();

/**
 * @see https://playwright.dev/docs/test-configuration
 */
export default defineConfig({
  testDir: path.join(path.resolve(process.cwd()), 'uat'),
  outputDir: path.join(process.cwd(), 'uat', 'test-results'),
  /* Run tests in files in parallel */
  fullyParallel: true,
  /* Fail the build on CI if you accidentally left test.only in the source code. */
  //forbidOnly: !!process.env.CI,
  /* Retry on CI only */
  retries: process.env.CI ? 2 : 0,
  /* Reporter to use. See https://playwright.dev/docs/test-reporters */
  reporter: [['html', { outputFolder: path.join(process.cwd(), 'uat', 'playwright-report'), open: "always" }]],
  timeout: 60 * 1000,
  expect: {
    timeout: 5 * 1000,
  },

  /* Shared settings for all the projects below. See https://playwright.dev/docs/api/class-testoptions. */
  use: {
    /* Base URL to use in actions like `await page.goto('/')`. */
    //baseURL: process.env.domain,

    /* Collect trace when retrying the failed test. See https://playwright.dev/docs/trace-viewer */
    trace: 'on',
    video: {
      mode: 'on',
      size: { width: 640, height: 480 }
    }
  },

  /* Configure projects for major browsers */
  projects: [
    { name: 'setup', testMatch: /.*\.setup\.js/ },
    {
      name: 'chromium',
      use: {
        ...devices['Desktop Chrome'],
        storageState: path.resolve(process.cwd(), 'uat', 'playwright/.auth/user.json')
      },
      dependencies: ['setup'],
    },

    {
      name: 'firefox',
      timeout: 4 * 60 * 1000,
      expect: {
        timeout: 80 * 1000,
      },
      use: {
        ...devices['Desktop Firefox'],
        storageState: path.resolve(process.cwd(), 'uat', 'playwright/.auth/user.json')
      },
      dependencies: ['setup'],
    },

    {
      name: 'webkit',
      timeout: 2 * 60 * 1000,
      expect: {
        timeout: 80 * 1000,
      },
      use: {
        ...devices['Desktop Safari'],
        storageState: path.resolve(process.cwd(), 'uat', 'playwright/.auth/user.json')
      },
      dependencies: ['setup'],
    },

    /* Test against mobile viewports. */
    // {
    //   name: 'Mobile Chrome',
    //   use: { ...devices['Pixel 5'] },
    // },
    // {
    //   name: 'Mobile Safari',
    //   use: { ...devices['iPhone 12'] },
    // },

    /* Test against branded browsers. */
    // {
    //   name: 'Microsoft Edge',
    //   use: { ...devices['Desktop Edge'], channel: 'msedge' },
    // },
    // {
    //   name: 'Google Chrome',
    //   use: { ...devices['Desktop Chrome'], channel: 'chrome' },
    // },
  ],

  /* Run your local dev server before starting the tests */
  // webServer: {
  //   command: 'npm run start',
  //   url: 'http://127.0.0.1:3000',
  //   reuseExistingServer: !process.env.CI,
  // },
});
